@@ -5,6 +5,7 @@ from logging import getLogger
 from flask import request
 
 from app import db
+from avatar_utils.db.mixins import CRUDMixin, TimeCastMixin
 
 logger = getLogger(__name__)
 
@@ -13,17 +14,18 @@ def format_text(text):
     return ' '.join(text.strip().split())
 
 
-class Log(db.Model):
+class Log(CRUDMixin, db.Model):
     __tablename__ = 'logs'
+
     id = db.Column(db.Integer(), primary_key=True)
-    route = db.Column(db.String(100))
-    method = db.Column(db.String(10))
-    request = db.Column(db.Text())
-    response = db.Column(db.Text())
-    ts = db.Column(db.DateTime(), default=datetime.utcnow)
-    duration = db.Column(db.Integer())
-    status_code = db.Column(db.String)
-    message = db.Column(db.String)
+    route = db.Column(db.String(), nullable=False)
+    method = db.Column(db.String(10), nullable=False)
+    request = db.Column(db.Text(), nullable=False)
+    response = db.Column(db.Text(), nullable=True)
+    ts = db.Column(db.DateTime(timezone=True), nullable=False, default=TimeCastMixin.utc_now)
+    duration = db.Column(db.Float(), nullable=True)
+    status_code = db.Column(db.String, nullable=True)
+    message = db.Column(db.String, nullable=True)
 
     def __repr__(self):
         return """<log object>
@@ -41,23 +43,16 @@ class Log(db.Model):
     @staticmethod
     def init(request):
         data = request.json
-        log = Log()
-        log.route = request.path
-        log.method = request.method
-        log.request = json.dumps(data)
-        db.session.add(log)
-        db.session.commit()
+        log = Log.create(route=request.path, method=request.method, request=json.dumps(data))
         return log
 
     @staticmethod
     def complete(log, response):
         if log:
-            log.duration = (datetime.utcnow() - log.ts).total_seconds()
-            log.status_code = response.status
+            log.update(duration=(datetime.utcnow() - log.ts).total_seconds(), status_code=response.status)
             try:
                 data = response.json
-                log.response = json.dumps(data)
-                log.message = data.get('message')
+                log.update(response=json.dumps(data), message=data.get('message'))
             except TypeError as err:
                 log_prefix = f'[ EVENT LOGGING | {request.remote_addr} {request.method} > {request.url_rule} ]'
                 logger.warning(f'{log_prefix} < Response is not in JSON format')
@@ -66,8 +61,3 @@ class Log(db.Model):
             db.session.commit()
             return True
         return False
-
-    def delete(self):
-        log = Log.query.filter_by(id=self.id).first()
-        db.session.delete(log)
-        db.session.commit()
