@@ -1,10 +1,12 @@
 from logging import getLogger
 
-from flask import g, request
+from flask import g
+from flask import request
 from sqlalchemy.exc import DatabaseError
 
+from app import db
 from . import logs
-from .models import *
+from .models import Log
 
 logger = getLogger(__name__)
 
